# Changelog

## [0.4.2](https://github.com/uptick/splat/compare/splat-v0.4.1...splat-v0.4.2) (2025-11-11)


### Maintenance

* chore(deps): update dependencies (awscli, boto3, sentry-sdk, requests)
* refactor: upgrade to Python 3.12 and Django 5.0+
* refactor: migrate from pip to uv for dependency management
* chore: configure Renovate for automated dependency updates

## [0.4.1](https://github.com/uptick/splat/compare/splat-v0.4.0...splat-v0.4.1) (2025-11-03)


### Bug Fixes

* add claude.md file ([f2552d5](https://github.com/uptick/splat/commit/f2552d58ac78e8f22ad61a2a4bb0e082a5885fd1))

## [0.4.0](https://github.com/uptick/splat/compare/splat-v0.3.3...splat-v0.4.0) (2025-10-23)


### Features

* upgrade princexml to 16 ([e9b520c](https://github.com/uptick/splat/commit/e9b520cebe0e0619ca2b2dfc9f265d4218cd1c5c))

## [0.3.3](https://github.com/uptick/splat/compare/splat-v0.3.2...splat-v0.3.3) (2025-01-14)


### Bug Fixes

* trigger another build ([254f130](https://github.com/uptick/splat/commit/254f1301b0f9e7f57694307554308889d2db1245))

## [0.3.2](https://github.com/uptick/splat/compare/splat-v0.3.1...splat-v0.3.2) (2025-01-13)


### Bug Fixes

* **playwright:** switch to the load event which is better than network idle ([8502d0c](https://github.com/uptick/splat/commit/8502d0c47fc7f545228e654655b5d14a8e86e3d7))

## [0.3.1](https://github.com/uptick/splat/compare/splat-v0.3.0...splat-v0.3.1) (2025-01-12)


### Bug Fixes

* **playwright:** extend wait for network timeout ([db1da1d](https://github.com/uptick/splat/commit/db1da1d1acd910355cab13f42220d756037ceb61))

## [0.3.0](https://github.com/uptick/splat/compare/splat-v0.2.0...splat-v0.3.0) (2024-12-02)


### Features

* Update container with new license ([de81478](https://github.com/uptick/splat/commit/de81478bd724d6521a2a8503653ea6c41c0aef21))

## [0.2.0](https://github.com/uptick/splat/compare/splat-v0.1.8...splat-v0.2.0) (2024-11-21)


### Features

* add ./splat_cli helper script ([4d3f3fc](https://github.com/uptick/splat/commit/4d3f3fc458941e04efb8a7e2e58ad15076dea1e9))
* add pdf_from_html_without_s3 mode to generate pdfs without an s3 bucket ([1f7764e](https://github.com/uptick/splat/commit/1f7764efa983e59436f0943b59cf296dacdee15e))
* add playwright rendering ([3821f92](https://github.com/uptick/splat/commit/3821f92e5f022370d16f7a212cdde3551d7c42a5))
* add py.typed ([5e34086](https://github.com/uptick/splat/commit/5e340862e443f7633da3660107ab3522adcd335f))
* allow html_key path to be configured ([1401af8](https://github.com/uptick/splat/commit/1401af88028d4968cb85a6520e3372c64f581d7e))
* **docker:** Add initial dockerfile ([b2f20ae](https://github.com/uptick/splat/commit/b2f20aefa6dd2a50e0d50b8c65fed5374cc200a8))
* **docs:** update documentation with configure_splat usage ([a56d8ea](https://github.com/uptick/splat/commit/a56d8ea44dcc83bdc426f3fa98d955b1936f3879))
* **playwright:** add browser launch kwargs ([d8bf769](https://github.com/uptick/splat/commit/d8bf769442cbd53925da8b75b3814f951c58ee22))
* **playwright:** add context variables to playwright ([57eca5d](https://github.com/uptick/splat/commit/57eca5db09ff8f73c7ab0e99a23d791c8bae53a1))
* **playwright:** add papersize argument ([6a70de6](https://github.com/uptick/splat/commit/6a70de6d6bcef3e3fdc6cf1afb75d833a79578a9))
* **playwright:** pdf options aren't str,str ([9bb5a32](https://github.com/uptick/splat/commit/9bb5a323c6ddc1e1a1ea5e5d7edbb9ce7e63a3f4))
* **playwright:** switch to configurable options ([e24c4c8](https://github.com/uptick/splat/commit/e24c4c842edaf586019d8ab0a71bc5863bce45fb))
* **splat:** add uptick_splat library ([00b2db0](https://github.com/uptick/splat/commit/00b2db04f639d2caec0d2356bfe1b467ec089bd6))


### Bug Fixes

* fix the types ([1b063b6](https://github.com/uptick/splat/commit/1b063b6a20fa1dada98f07f01868c72a546f7785))
* **playwright:** fix papersize argument ([6302389](https://github.com/uptick/splat/commit/6302389094c2d3e0bffb45f663e061400a4d5e1b))
* **splat:** update read timeout to 15 minutes ([95a1706](https://github.com/uptick/splat/commit/95a1706f40e2f1b71f5dc331f7a0efa5b7be3086))
* **splat:** wipe tmp directory after run ([5ebee41](https://github.com/uptick/splat/commit/5ebee419bff46a9c8569c33f2dcd8690d3a5bcbf))


### Documentation

* improve documentation ([b771ca9](https://github.com/uptick/splat/commit/b771ca984e24ea9c16e8a6fa20e374633fea9b97))
* include local dev instructions ([5396853](https://github.com/uptick/splat/commit/5396853ee7d8e258bec7abb45cdd28b77488c4d6))
